@@ -1,6 +1,8 @@
 if (.Platform$OS.type != "windows") {
 
     library(lme4)
+    source(system.file("testdata", "lme-tst-funs.R", package="lme4", mustWork=TRUE))# -> unn()
+
     m <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
     bruteForceHat <- function(object) {
         with(getME(object, c("Lambdat", "Lambda", "Zt", "Z", "q", "X")), {
@@ -25,8 +27,8 @@ if (.Platform$OS.type != "windows") {
     m2 <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy[ii, ])
 
     stopifnot(all.equal(diag(H),
-                        unname(lme4:::hatvalues.merMod(m)), tol= 1e-14),
+                        unn(lme4:::hatvalues.merMod(m)),  tol= 1e-14),
               all.equal(diag(bruteForceHat(m2)),
-                        unname(lme4:::hatvalues.merMod(m2)), tol= 1e-14)
+                        unn(lme4:::hatvalues.merMod(m2)), tol= 1e-14)
               )
 } ## skip on windows (for speed)
