@@ -1,6 +1,8 @@
 library("testthat")
 library("lme4")
+testLevel <- if (nzchar(s <- Sys.getenv("LME4_TEST_LEVEL"))) as.numeric(s) else 1
 
+if (testLevel>1) {
 context("glmer.nb")
 test_that("basic", {
    set.seed(101)
@@ -66,4 +68,4 @@ test_that("basic", {
                          offset=rep(0,nrow(dd)))
 })
 
-
+} ## testLevel > 1
